# -*- coding: utf-8 -*-
VERSION = '1.2.2-beta'

from .conf import Configuration
from .template import ProjectCreator


